@@ -5,29 +5,39 @@ use lscolors::{Indicator, LsColors, Style};
 
 use crate::config::Config;
 use crate::dir_entry::DirEntry;
-use crate::error::print_error;
-use crate::exit_codes::ExitCode;
+use crate::fmt::FormatTemplate;
+use crate::hyperlink::PathUrl;
 
 fn replace_path_separator(path: &str, new_path_separator: &str) -> String {
     path.replace(std::path::MAIN_SEPARATOR, new_path_separator)
 }
 
 // TODO: this function is performance critical and can probably be optimized
-pub fn print_entry<W: Write>(stdout: &mut W, entry: &DirEntry, config: &Config) {
-    let r = if let Some(ref ls_colors) = config.ls_colors {
-        print_entry_colorized(stdout, entry, config, ls_colors)
+pub fn print_entry<W: Write>(stdout: &mut W, entry: &DirEntry, config: &Config) -> io::Result<()> {
+    let mut has_hyperlink = false;
+    if config.hyperlink {
+        if let Some(url) = PathUrl::new(entry.path()) {
+            write!(stdout, "\x1B]8;;{}\x1B\\", url)?;
+            has_hyperlink = true;
+        }
+    }
+
+    if let Some(ref format) = config.format {
+        print_entry_format(stdout, entry, config, format)?;
+    } else if let Some(ref ls_colors) = config.ls_colors {
+        print_entry_colorized(stdout, entry, config, ls_colors)?;
     } else {
-        print_entry_uncolorized(stdout, entry, config)
+        print_entry_uncolorized(stdout, entry, config)?;
     };
 
-    if let Err(e) = r {
-        if e.kind() == ::std::io::ErrorKind::BrokenPipe {
-            // Exit gracefully in case of a broken pipe (e.g. 'fd ... | head -n 3').
-            ExitCode::Success.exit();
-        } else {
-            print_error(format!("Could not write to output: {}", e));
-            ExitCode::GeneralError.exit();
-        }
+    if has_hyperlink {
+        write!(stdout, "\x1B]8;;\x1B\\")?;
+    }
+
+    if config.null_separator {
+        write!(stdout, "\0")
+    } else {
+        writeln!(stdout)
     }
 }
 
@@ -54,6 +64,21 @@ fn print_trailing_slash<W: Write>(
     Ok(())
 }
 
+// TODO: this function is performance critical and can probably be optimized
+fn print_entry_format<W: Write>(
+    stdout: &mut W,
+    entry: &DirEntry,
+    config: &Config,
+    format: &FormatTemplate,
+) -> io::Result<()> {
+    let output = format.generate(
+        entry.stripped_path(config),
+        config.path_separator.as_deref(),
+    );
+    // TODO: support writing raw bytes on unix?
+    write!(stdout, "{}", output.to_string_lossy())
+}
+
 // TODO: this function is performance critical and can probably be optimized
 fn print_entry_colorized<W: Write>(
     stdout: &mut W,
@@ -103,12 +128,6 @@ fn print_entry_colorized<W: Write>(
         ls_colors.style_for_indicator(Indicator::Directory),
     )?;
 
-    if config.null_separator {
-        write!(stdout, "\0")?;
-    } else {
-        writeln!(stdout)?;
-    }
-
     Ok(())
 }
 
@@ -118,7 +137,6 @@ fn print_entry_uncolorized_base<W: Write>(
     entry: &DirEntry,
     config: &Config,
 ) -> io::Result<()> {
-    let separator = if config.null_separator { "\0" } else { "\n" };
     let path = entry.stripped_path(config);
 
     let mut path_string = path.to_string_lossy();
@@ -126,8 +144,7 @@ fn print_entry_uncolorized_base<W: Write>(
         *path_string.to_mut() = replace_path_separator(&path_string, separator);
     }
     write!(stdout, "{}", path_string)?;
-    print_trailing_slash(stdout, entry, config, None)?;
-    write!(stdout, "{}", separator)
+    print_trailing_slash(stdout, entry, config, None)
 }
 
 #[cfg(not(unix))]
@@ -152,9 +169,7 @@ fn print_entry_uncolorized<W: Write>(
         print_entry_uncolorized_base(stdout, entry, config)
     } else {
         // Print path as raw bytes, allowing invalid UTF-8 filenames to be passed to other processes
-        let separator = if config.null_separator { b"\0" } else { b"\n" };
         stdout.write_all(entry.stripped_path(config).as_os_str().as_bytes())?;
-        print_trailing_slash(stdout, entry, config, None)?;
-        stdout.write_all(separator)
+        print_trailing_slash(stdout, entry, config, None)
     }
 }
