@@ -12,7 +12,7 @@ use anyhow::{anyhow, Result};
 use crossbeam_channel::{bounded, Receiver, RecvTimeoutError, SendError, Sender};
 use etcetera::BaseStrategy;
 use ignore::overrides::{Override, OverrideBuilder};
-use ignore::{self, WalkBuilder, WalkParallel, WalkState};
+use ignore::{WalkBuilder, WalkParallel, WalkState};
 use regex::bytes::Regex;
 
 use crate::config::Config;
@@ -250,7 +250,12 @@ impl<'a, W: Write> ReceiverBuffer<'a, W> {
 
     /// Output a path.
     fn print(&mut self, entry: &DirEntry) -> Result<(), ExitCode> {
-        output::print_entry(&mut self.stdout, entry, &self.config);
+        if let Err(e) = output::print_entry(&mut self.stdout, entry, self.config) {
+            if e.kind() != ::std::io::ErrorKind::BrokenPipe {
+                print_error(format!("Could not write to output: {}", e));
+                return Err(ExitCode::GeneralError);
+            }
+        }
 
         if self.interrupt_flag.load(Ordering::Relaxed) {
             // Ignore any errors on flush, because we're about to exit anyway
@@ -334,10 +339,6 @@ impl WorkerState {
                 .map_err(|e| anyhow!("Malformed exclude pattern: {}", e))?;
         }
 
-        if config.read_vcsignore {
-            builder.add("!.git/").expect("Invalid exclude pattern");
-        }
-
         builder
             .build()
             .map_err(|_| anyhow!("Mismatch in exclude patterns"))
@@ -413,7 +414,7 @@ impl WorkerState {
         // This will be set to `Some` if the `--exec` argument was supplied.
         if let Some(ref cmd) = config.command {
             if cmd.in_batch_mode() {
-                exec::batch(rx.into_iter().flatten(), cmd, &config)
+                exec::batch(rx.into_iter().flatten(), cmd, config)
             } else {
                 let out_perm = Mutex::new(());
 
@@ -426,7 +427,7 @@ impl WorkerState {
 
                         // Spawn a job thread that will listen for and execute inputs.
                         let handle = scope
-                            .spawn(|| exec::job(rx.into_iter().flatten(), cmd, &out_perm, &config));
+                            .spawn(|| exec::job(rx.into_iter().flatten(), cmd, &out_perm, config));
 
                         // Push the handle of the spawned thread into the vector for later joining.
                         handles.push(handle);
